<?php

namespace Drupal\commerce_cart_refresh\EventSubscriber;

use Drupal\commerce_product\Event\ProductEvents;
use Drupal\commerce_product\Event\ProductVariationAjaxChangeEvent;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Event subscriber that handles cloning through the Replicate module.
 */
class ProductEventsSubscriber implements EventSubscriberInterface {

  use StringTranslationTrait;

  /**
   * Event fired when filtering variations.
   *
   * @param \Drupal\commerce_product\Event\ProductVariationAjaxChangeEvent $event
   */
  public function onVariationAjaxChange(ProductVariationAjaxChangeEvent $event) {
    // Defaults.
    $quantity  = 1;
    $ccrm      = \Drupal::service('commerce_cart_refresh.manager');
    $response  = $event->getResponse();
    $variation = $event->getProductVariation();
    
    $vid = $variation->id();

    // Try to extract the $form_state from event.
    // You need to apply this patch: https://www.drupal.org/project/commerce/issues/3019102
    if (method_exists($event, 'getFormState')) {
      $form_state = $event->getFormState();
      $input      = $form_state->getUserInput();
      $quantity   = isset($input['quantity'][0]['value']) ? (float) $input['quantity'][0]['value'] : $qty;
    }

    if ($quantity > 1) {
      // Update the price based on quantity.
      $price_dom_selector = $ccrm->getPriceDomSelector($variation);
      $calculated_price   = $ccrm->getCalculatedPrice($quantity, $variation);

      // Remove existing Price update commands.
      $commands = &$response->getCommands();
      foreach ($commands as $delta => $command) {
        if ($command['selector'] == '.' . $price_dom_selector) {
          unset($commands[$delta]);
        }
      }

      // Add custom Price update command.
      $response->addCommand(new ReplaceCommand('#' . $price_dom_selector, [
        '#prefix' => '<span id="' . $price_dom_selector . '">',
        '#markup' => $calculated_price,
        '#suffix' => '</span>',
      ]));
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[ProductEvents::PRODUCT_VARIATION_AJAX_CHANGE][] = ['onVariationAjaxChange', 999];
    return $events;
  }

}
